.. _quantum-oscillator:

quantum/oscillator.py
=====================

**Description**


Quantum oscillator.

See :ref:`quantum-quantum_common`.


.. image:: /../doc/images/gallery/quantum-oscillator.png


:download:`source code </../sfepy/examples/quantum/oscillator.py>`

.. literalinclude:: /../sfepy/examples/quantum/oscillator.py

